summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rwxr-xr-xrun.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/run.sh b/run.sh
index 04b3052..4bfe7e6 100755
--- a/run.sh
+++ b/run.sh
@@ -18,12 +18,12 @@ if [ ! -x $logDir ]; then
mkdir -p $logDir
fi
-nohup python manage.py runserver 0.0.0.0:8806 > /dev/null &
-# nohup uwsgi --http :8806 -t 120 --module catalog.wsgi --master --processes 4 &
+nohup python manage.py runserver 0.0.0.0:8280 > /dev/null &
+# nohup uwsgi --http :8280 -t 120 --module catalog.wsgi --master --processes 4 &
# if [ "${SSL_ENABLED}" = "true" ]; then
# nohup uwsgi --https :8806,catalog/pub/ssl/cert/foobar.crt,catalog/pub/ssl/cert/foobar.key, -t 120 --enable-threads --module catalog.wsgi --master --processes 4 &
# else
# nohup uwsgi --http :8806 -t 120 --enable-threads --module catalog.wsgi --master --processes 4 &
# fi
@@ -18,12 +18,12 @@ if [ ! -x $logDir ]; then
# if [ "${SSL_ENABLED}" = "true" ]; then
-# nohup uwsgi --https :8806,catalog/pub/ssl/cert/foobar.crt,catalog/pub/ssl/cert/foobar.key, -t 120 --enable-threads --module catalog.wsgi --master --processes 4 &
+# nohup uwsgi --https :8280,catalog/pub/ssl/cert/foobar.crt,catalog/pub/ssl/cert/foobar.key, -t 120 --enable-threads --module catalog.wsgi --master --processes 4 &
# else
@@ -18,12 +18,12 @@ if [ ! -x $logDir ]; then
# else
-# nohup uwsgi --http :8806 -t 120 --enable-threads --module catalog.wsgi --master --processes 4 &
+# nohup uwsgi --http :8280 -t 120 --enable-threads --module catalog.wsgi --master --processes 4 &
# fi